@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -482,7 +482,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
   }
 
   if (before_ptr != NULL)
-    g_sequence_move (new_ptr, g_sequence_iter_prev (before_ptr));
+    g_sequence_move (new_ptr, before_ptr);
 
   g_hash_table_insert (model->reverse_map, pointer, new_ptr);
 
