@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -47,7 +47,7 @@ namespace Muine
 		
 		// Authors
 		private static readonly string [] authors = {
-			Catalog.GetString ("Jorn Baayen <jbaayen@gnome.org>"),
+			Catalog.GetString ("Jorn Baayen <jorn.baayen@gmail.com>"),
 			Catalog.GetString ("Lee Willis <lee@leewillis.co.uk>"),
 			Catalog.GetString ("Việt Yên Nguyễn <nguyen@cs.utwente.nl>"),
 			Catalog.GetString ("Tamara Roberson <tamara.roberson@gmail.com>"),
@@ -96,7 +96,7 @@ namespace Muine
 			base.Comments          = string_description;
 			base.Documenters       = documenters;
 			base.Logo              = pixbuf;
-			base.Name              = string_muine;
+			base.ProgramName       = string_muine;
 			base.TranslatorCredits = translators;
 			base.Version           = Defines.VERSION;
 			base.Website           = string_website;
