@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005 Tamara Roberson <tamara.roberson@gmail.com>
- *           (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ *           (C) 2003, 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -23,7 +23,7 @@ using System.Collections;
 
 namespace Muine
 {
-	public abstract class AddWindow : Gtk.Window
+	public abstract class AddWindow : Gtk.Dialog
 	{
 #region Enums
 #region Enums.ResponseType
@@ -116,6 +116,9 @@ namespace Muine
 			this.entry_container.Add (this.entry);
 
 			// List
+			this.Response               += OnWindowResponse;
+			this.DeleteEvent            += OnWindowDeleteEvent;
+
 			this.list.RowActivated      += OnRowActivated;
 			this.list.Selection.Changed += OnSelectionChanged;
 			scrolledwindow.Add (this.list);
@@ -175,7 +178,7 @@ namespace Muine
 				this.window.GdkWindow.Display.Flush ();
 
 				this.ignore_change = true;
-				this.entry.Text = "";
+				this.entry.Text = String.Empty;
 				this.ignore_change = false;
 
 				GLib.IdleHandler func = new GLib.IdleHandler (ResetFunc);
