@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,15 +22,25 @@ using System.Runtime.InteropServices;
 
 namespace Muine
 {
+	/// <summary>
+	/// </summary>
+	/// <remarks>
+	///	This renderer is similar to <see cref="Gtk.CellRendererPixbuf" />.
+	/// </remarks>
 	public class ColoredCellRendererPixbuf : Gtk.CellRenderer 
 	{
 		// Constructor
 		[DllImport ("libmuine")]
 		private static extern IntPtr rb_cell_renderer_pixbuf_new ();
 
+		/// <summary>
+		///	Create a new <see cref="ColoredCellRendererPixbuf" />
+		///	object.
+		/// </summary>
 		public ColoredCellRendererPixbuf () : base (IntPtr.Zero)
 		{
 			base.Raw = rb_cell_renderer_pixbuf_new ();
+                        System.Console.WriteLine("hi");
 		}
 
 		// Destructor
@@ -41,6 +51,12 @@ namespace Muine
 
 		// Properties
 		// Properties :: Pixbuf (set;)
+		/// <summary>
+		///	The <see cref="Gdk.Pixbuf" /> to be used.
+		/// </summary>
+		/// <param name="value">
+		///	A <see cref="Gdk.Pixbuf" />.
+		/// </param>
 		public Gdk.Pixbuf Pixbuf {
 			set { SetProperty ("pixbuf", new GLib.Value (value)); }
 		}
