@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -29,8 +29,7 @@ namespace Muine
 	public class ErrorDialog
 	{
 		// Widgets
-		[Glade.Widget] private Dialog window;
-		[Glade.Widget] private Label  label;
+		private MessageDialog window;
 
 		// Constructor
 		//	TODO: Shouldn't the ErrorDialog be able to be
@@ -66,18 +65,16 @@ namespace Muine
 		/// </param>
 		public ErrorDialog (string s1, string s2)
 		{
-			Glade.XML gxml =
-			  new Glade.XML (null, "ErrorDialog.glade", "window", null);
-
-			gxml.Autoconnect (this);
-
-			string fmt =
-			  "<span size=\"large\" weight=\"bold\">{0}</span>\n\n{1}";
-
 			string s1_esc = StringUtils.EscapeForPango (s1);
 			string s2_esc = StringUtils.EscapeForPango (s2);
 
-			label.Markup = String.Format (fmt, s1_esc, s2_esc);
+			string markup = String.Format ("<span size=\"large\" weight=\"bold\">{0}</span>", s1_esc);
+
+			window = new Gtk.MessageDialog (null, DialogFlags.DestroyWithParent,
+							MessageType.Error, ButtonsType.Close, true, markup);
+
+			window.SecondaryText = s2_esc;
+			window.Title = Catalog.GetString("Error");
 
 			window.Run ();
 			window.Destroy ();
