@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -75,7 +75,7 @@ namespace Muine
 			  (string) Config.Get (gconf_path, GConfDefaultStartDir);
 
 			start_dir = start_dir.Replace ("~",
-				FileUtils.UriFromLocalPath (FileUtils.HomeDirectory));
+				Gnome.Vfs.Uri.GetUriFromLocalPath (FileUtils.HomeDirectory));
 
 			SetCurrentFolderUri (start_dir);
 
