@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,12 +13,14 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
 using System.IO;
+using System.Runtime.InteropServices;
+using System.Text;
 
 using Gtk;
 using GLib;
@@ -109,8 +111,11 @@ namespace Muine
 		{
 			try {
 				NDesk.DBus.BusG.Init ();
-			} catch {
-			}
+			} catch {}
+
+			try {
+				Global.SetProcessName ("muine");
+			} catch {}
 
 			Application.Init ();
 			Gnome.Vfs.Vfs.Initialize ();
@@ -213,7 +218,9 @@ namespace Muine
 			new PluginManager (playlist);
 
 			// Hook up multimedia keys
-			new MmKeys (playlist);
+			if (!GnomeMMKeys.Initialize ()) {
+				new MmKeys (playlist);
+			}
 
 			// Process command line options
 			bool opened_file = ProcessCommandLine (args);
@@ -247,6 +254,9 @@ namespace Muine
 		/// </summary>
 		public static void Exit ()
 		{
+			if (GnomeMMKeys.IsLoaded) {
+				GnomeMMKeys.Shutdown ();
+			}
 			Environment.Exit (0);
 		}
 
@@ -381,5 +391,18 @@ namespace Muine
 
 			session_client.SetRestartCommand (1, argv);
 		}
+
+		[DllImport ("libc")]
+		private static extern int prctl (int option,  
+						 byte[] arg2,
+						 ulong arg3,
+						 ulong arg4,
+						 ulong arg5);
+		public static void SetProcessName (string name)
+		{
+			if (prctl (15, Encoding.ASCII.GetBytes (name + "\0"), 0, 0, 0) != 0) {
+				throw new ApplicationException ("Error setting process name: " + Mono.Unix.Native.Stdlib.GetLastError ());
+			}
+		}
 	}
 }
