@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -489,12 +489,10 @@ namespace Muine
 		}
 
 		[DllImport("libgtk-2.0-0.dll")]
-		static extern void gtk_tree_model_rows_reordered(IntPtr raw, IntPtr path, ref Gtk.TreeIter iter, out int new_order);
+		static extern void gtk_tree_model_rows_reordered(IntPtr raw, IntPtr path, ref Gtk.TreeIter iter, out int[] new_order);
 
-		public int EmitRowsReordered(Gtk.TreePath path, Gtk.TreeIter iter) {
-			int new_order;
+		public void EmitRowsReordered(Gtk.TreePath path, Gtk.TreeIter iter, int[] new_order) {
 			gtk_tree_model_rows_reordered(Handle, path.Handle, ref iter, out new_order);
-			return new_order;
 		}
 
 		[DllImport("libgtk-2.0-0.dll")]
