@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -36,12 +36,10 @@ namespace Muine
 			this.model = new HandleModel ();
 			((TreeView) this).Model = model;
 
-			RulesHint      = true;
-			EnableSearch   = false;
-			HeadersVisible = false;
-
-			// FIXME: Re-enable when Gnome Bugzilla #165017, #165034 are fixed
-			// SetProperty ("fixed_height_mode", new GLib.Value (true));
+			RulesHint       = true;
+			EnableSearch    = false;
+			HeadersVisible  = false;
+                        FixedHeightMode = true;
 		}
 
 		// Properties
