@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2005 Tamara Roberson <foxxygirltamara@gmail.com>
- * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2005 Tamara Roberson <tamara.roberson@gmail.com>
+ * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,15 +14,15 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
 using System.Collections;
 using System.IO;
 using Gtk;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Muine
 {
@@ -41,7 +41,8 @@ namespace Muine
 
 		// Constructor
 		public OpenDialog () 
-		: base (string_title, FileChooserAction.Open, GConfKeyDefaultPlaylistFolder)
+		  : base (string_title, FileChooserAction.Open,
+		  GConfKeyDefaultPlaylistFolder)
 		{
 			FileFilter filter = new FileFilter ();
 			filter.Name = string_filter;
@@ -49,7 +50,7 @@ namespace Muine
 			filter.AddPattern ("*.m3u");
 			base.AddFilter (filter);
 
-			base.Response += new ResponseHandler (OnResponse);
+			base.Response += OnResponse;
 
 			base.Visible = true;
 		}
@@ -59,14 +60,13 @@ namespace Muine
 		private void OnResponse (object o, ResponseArgs args)
 		{
 			if (args.ResponseId != ResponseType.Ok) {
-			        base.Destroy ();
-
+				base.Destroy ();
 				return;
-                        }
+			}
 
 			string fn = base.Uri;
 
-                        base.Destroy ();
+			base.Destroy ();
 
 			if (!FileUtils.IsPlaylist (fn))
 				return;
