@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -24,6 +24,7 @@ using System.IO;
 using Gtk;
 using GLib;
 using Gnome.Vfs;
+using Bacon;
 
 using Mono.Unix;
 
@@ -58,6 +59,12 @@ namespace Muine
 		// GConf :: Height
 		private const string GConfKeyHeight = "/apps/muine/playlist_window/height";
 		private const int    GConfDefaultHeight = 450;
+		
+		private const string GConfKeyPosX = "/apps/muine/playlist_window/pos_x";
+		private const int    GConfDefaultPosX = 0; 
+
+		private const string GConfKeyPosY = "/apps/muine/playlist_window/pos_y";
+		private const int    GConfDefaultPosY = 0;
 
 		// GConf :: Volume
 		private const string GConfKeyVolume = "/apps/muine/volume";
@@ -120,7 +127,7 @@ namespace Muine
 
 		// Strings :: Errors
 		private static readonly string string_error_audio =
-			Catalog.GetString ("Failed to initialize the audio backend:\n{0}");
+			Catalog.GetString ("Failed to initialize the audio backend");
 
 		private static readonly string string_error_read =
 			Catalog.GetString ("Failed to read {0}:");
@@ -159,10 +166,9 @@ namespace Muine
 		[Glade.Widget] private Box            menu_bar_box  ;
 		[Glade.Widget] private ScrolledWindow scrolledwindow;
 
-		private Tooltips         tooltips       ;
-		private Gdk.Pixbuf       empty_pixbuf   ;
-		private CellRenderer     pixbuf_renderer;
-		private CellRendererText text_renderer  ;
+		private Gdk.Pixbuf                empty_pixbuf   ;
+		private CellRendererText          text_renderer  ;
+		private ColoredCellRendererPixbuf pixbuf_renderer;
 		
 		// Widgets :: Containers
 		[Glade.Widget] private Container volume_button_container;
@@ -175,7 +181,7 @@ namespace Muine
 		[Glade.Widget] private Button       add_song_button   ;
 		[Glade.Widget] private Button       add_album_button  ;		
 
-		private VolumeButton volume_button;
+		private Bacon.VolumeButton volume_button;
 
 		// Widgets :: Player
 		[Glade.Widget] private Label song_label;
@@ -451,6 +457,7 @@ namespace Muine
 		// Methods :: Public :: Quit (IPlayer)
 		public void Quit ()
 		{
+			SaveWindowPosition ();
 			Global.Exit ();
 		}
 
@@ -868,19 +875,18 @@ namespace Muine
 			add_album_button  .Clicked += OnAddAlbumButtonClicked;
 
 			// Volume
-			volume_button = new VolumeButton ();
+			volume_button = new Bacon.VolumeButton ();
 			volume_button_container.Add (volume_button);
 			volume_button.Visible = true;
 			volume_button.VolumeChanged += OnVolumeChanged;
 
 			// Tooltips
-			tooltips = new Tooltips ();
-			tooltips.SetTip (toggle_play_button, string_tooltip_toggle_play, null);
-			tooltips.SetTip (previous_button   , string_tooltip_previous   , null);
-			tooltips.SetTip (next_button       , string_tooltip_next       , null);
-			tooltips.SetTip (add_album_button  , string_tooltip_add_album  , null);
-			tooltips.SetTip (add_song_button   , string_tooltip_add_song   , null);
-			tooltips.SetTip (volume_button     , string_tooltip_volume     , null);
+			next_button.TooltipText	       = string_tooltip_next;
+			volume_button.TooltipText      = string_tooltip_volume;
+			add_song_button.TooltipText    = string_tooltip_add_song;
+			previous_button.TooltipText    = string_tooltip_previous;
+			add_album_button.TooltipText   = string_tooltip_add_album;
+			toggle_play_button.TooltipText = string_tooltip_toggle_play;
 		}
 
 		// Methods :: Private :: SetupPlaylist
@@ -890,7 +896,12 @@ namespace Muine
 
 			playlist.Selection.Mode = SelectionMode.Multiple;
 
+			/* Stock Cell Renderer
+			pixbuf_renderer = new Gtk.CellRendererPixbuf ();
+                        pixbuf_renderer.FollowState = true;
+			*/
 			pixbuf_renderer = new ColoredCellRendererPixbuf ();
+
 			text_renderer   = new Gtk.CellRendererText ();
 			text_renderer.Ellipsize = Pango.EllipsizeMode.End;
 
@@ -943,8 +954,7 @@ namespace Muine
 				player = new Player ();
 
 			} catch (Exception e) {
-				string msg = String.Format (string_error_audio, e.Message);
-				throw new Exception (msg);
+				throw new Exception (string_error_audio, e);
 			}
 
 			// Setup Player
@@ -1050,7 +1060,7 @@ namespace Muine
 		private void UpdateTimeLabels (int time)
 		{
 			if (playlist.Model.Playing == IntPtr.Zero) {
-				time_label.Text = "";
+				time_label.Text = String.Empty; 
 				playlist_label.Markup = string_playlist;
 				return;
 			}
@@ -1186,25 +1196,32 @@ namespace Muine
 		private void SongChanged (bool restart, bool fire_signal)
 		{
 			if (playlist.Model.Playing != IntPtr.Zero) {
+				string tip;
 				Song song = Song.FromHandle (playlist.Model.Playing);
 
 				cover_image.Song = song;
 
-				string tip;
+				cover_image.HasTooltip = true;
 
 				if (song.Album.Length > 0)
 					tip = String.Format (string_from_album, song.Album);
 				else
 					tip = string_album_unknown;
 
-				if (song.Performers.Length > 0)
-					tip += "\n\n" + String.Format (string_performers, 
-						StringUtils.JoinHumanReadable (song.Performers));
+				if (song.Performers.Length > 0) {
+					tip += Environment.NewLine;
+					tip += Environment.NewLine;
+					string performers_readable = StringUtils.JoinHumanReadable (song.Performers);
+					tip += String.Format (string_performers, performers_readable); 
+				}
 					
-				if (song.CoverImage == null && !Global.CoverDB.Loading)
-					tip += "\n\n" + string_tooltip_cover;
+				if (song.CoverImage == null && !Global.CoverDB.Loading) {
+					tip += Environment.NewLine;
+					tip += Environment.NewLine;
+					tip += string_tooltip_cover;
+				}
 				
-				tooltips.SetTip (cover_image, tip, null);
+				cover_image.TooltipText = tip;
 				
 				// Song label
 				string title = StringUtils.EscapeForPango (song.Title);
@@ -1214,10 +1231,10 @@ namespace Muine
 
 				string artists = StringUtils.EscapeForPango (artists_tmp);
 
-				string fmt =
-				  "<span size=\"large\" weight=\"bold\">{0}</span>\n{1}";
-
-				song_label.Markup = String.Format (fmt, title, artists);
+				string markup = String.Format ("<span size=\"large\" weight=\"bold\">{0}</span>", title);
+				markup += Environment.NewLine;
+				markup += artists;
+				song_label.Markup = markup;
 
 				// Title
 				this.Title = String.Format (string_title_main, song.Title);
@@ -1231,10 +1248,10 @@ namespace Muine
 			} else {
 				cover_image.Song = null;
 
-				tooltips.SetTip (cover_image, null, null);
+				cover_image.HasTooltip = false;
 
-				song_label.Markup = "";
-				time_label  .Text = "";
+				song_label.Markup = String.Empty;
+				time_label.Text   = String.Empty;
 
 				this.Title = string_program;
 
@@ -1335,7 +1352,7 @@ namespace Muine
 				// DOS-to-UNIX
 				line.Replace ('\\', '/');
 
-				string basename = "";
+				string basename = String.Empty;
 
 				try {
 					basename = System.IO.Path.GetFileName (line);
@@ -1495,7 +1512,12 @@ namespace Muine
 			int width  = (int) Config.Get (GConfKeyWidth , GConfDefaultWidth );
 			int height = (int) Config.Get (GConfKeyHeight, GConfDefaultHeight);
 
+			// Window position
+			int pos_x = (int) Config.Get (GConfKeyPosX, GConfDefaultPosX);
+			int pos_y = (int) Config.Get (GConfKeyPosY, GConfDefaultPosY);
+
 			SetDefaultSize (width, height);
+			Move (pos_x, pos_y);
 
 			SizeAllocated += OnSizeAllocated;
 
@@ -1511,6 +1533,18 @@ namespace Muine
 			Config.AddNotify (GConfKeyRepeat,
 				new GConf.NotifyEventHandler (OnConfigRepeatChanged));
 		}
+		
+		//Methods:: Private :: SaveWindowPosition
+		private void SaveWindowPosition ()
+		{
+			// Get Window position
+			int pos_x, pos_y;
+			GetPosition (out pos_x, out pos_y);
+
+			// Save it to GConf
+			Config.Set (GConfKeyPosX , pos_x );
+			Config.Set (GConfKeyPosY, pos_y);
+		}
 
 		// Handlers
 		// Handlers :: OnStateChanged
@@ -1879,13 +1913,13 @@ namespace Muine
 
 			switch (args.Info) {
 			case (uint) DndUtils.TargetType.UriList:
-				string files = "";
+				string files = String.Empty;
 
 				foreach (int p in songs) {
 					IntPtr s = new IntPtr (p);
 					
 					Song song = Song.FromHandle (s);
-					string uri = FileUtils.UriFromLocalPath (song.Filename);
+					string uri = Gnome.Vfs.Uri.GetUriFromLocalPath (song.Filename);
 					
 					files += (uri + "\r\n");
 				}
@@ -1970,9 +2004,9 @@ namespace Muine
 			string head;
 			
 			if      (is_tree_model) head = tree_model_row;
-			else if (is_song_list ) head = song_list     ;
-			else if (is_album_list) head = album_list    ;
-			else                    head = ""            ;
+			else if (is_song_list ) head = song_list;
+			else if (is_album_list) head = album_list;
+			else                    head = String.Empty;
 
 			data = data.Substring (head.Length);
 
@@ -2058,7 +2092,7 @@ namespace Muine
 				ArrayList new_dinfos = new ArrayList ();
 
 				foreach (string s in bits) {
-					string fn = FileUtils.LocalPathFromUri (s);
+					string fn = Gnome.Vfs.Uri.GetLocalPathFromUri (s);
 
 					if (fn == null)
 						continue;
@@ -2163,7 +2197,7 @@ namespace Muine
 
 				SavePlaylist (file, false, false);
 				
-				string uri = FileUtils.UriFromLocalPath (file);
+				string uri = Gnome.Vfs.Uri.GetUriFromLocalPath (file);
 
 				string target = DndUtils.TargetUriList.Target;
 				Gdk.Atom atom = Gdk.Atom.Intern (target, false);
@@ -2192,7 +2226,7 @@ namespace Muine
 			bool success = false;
 
 			foreach (string s in bits) {
-				string fn = FileUtils.LocalPathFromUri (s);
+				string fn = Gnome.Vfs.Uri.GetLocalPathFromUri (s);
 
 				if (fn == null)
 					continue;
@@ -2231,7 +2265,11 @@ namespace Muine
 		  (TreeViewColumn col, CellRenderer cell, TreeModel model,
 		   TreeIter iter)
 		{
+			/*
+			Gtk.CellRendererPixbuf r = (Gtk.CellRendererPixbuf) cell;
+			*/
 			ColoredCellRendererPixbuf r = (ColoredCellRendererPixbuf) cell;
+
 			IntPtr handle = playlist.Model.HandleFromIter (iter);
 
 			if (handle == playlist.Model.Playing) {
@@ -2255,8 +2293,11 @@ namespace Muine
 			string title = StringUtils.EscapeForPango (song.Title);
 			string artists_tmp = StringUtils.JoinHumanReadable (song.Artists);
 			string artists = StringUtils.EscapeForPango (artists_tmp);
-			string fmt = "<b>{0}</b>\n{1}";
-			r.Markup = String.Format (fmt, title, artists);
+
+			string markup = String.Format ("<b>{0}</b>", title);
+			markup += Environment.NewLine;
+			markup += artists;
+			r.Markup = markup;
 		}
 
 		// Delegate Functions :: ShuffleFunc		
