@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -135,6 +135,37 @@ namespace Muine
 
 			UpdateLabel ((int) song_slider.Value);
 		}
+		
+		// Handlers :: OnSongSliderKeyPressEvent
+		[GLib.ConnectBefore]
+		public void OnSongSliderKeyPressEvent (object obj, KeyPressEventArgs args)
+		{
+			switch (args.Event.Key) {
+			case Gdk.Key.Left:
+				Global.Playlist.SkipBackwards ();
+				args.RetVal = true;
+				break;
+			case Gdk.Key.Right:
+				Global.Playlist.SkipForward ();
+				args.RetVal = true;
+				break;
+
+			default:
+				break;
+			}
+		}
+
+		// Handlers :: OnScrollEvent
+		[GLib.ConnectBefore]
+			private void OnScrollEvent(object o, ScrollEventArgs args)
+		{
+			if(args.Event.Direction == Gdk.ScrollDirection.Up) {
+				Global.Playlist.SkipBackwards ();
+			} else if(args.Event.Direction == Gdk.ScrollDirection.Down) {
+				Global.Playlist.SkipForward ();
+			}
+			args.RetVal = true;
+		}
 
 		// Handlers :: OnWindowDeleteEvent
 		public void OnWindowDeleteEvent (object o, DeleteEventArgs a)
